closeHandle method

  1. @override
Future<void> closeHandle({
  1. required int handleId,
})
override

Releases the claimed interface and closes the libusb device handle. Also terminates the worker isolate that owned the handle.

Implementation

@override
Future<void> closeHandle({required int handleId}) async {
  _handles.remove(handleId);
}