UsbOpenResult class

Result of a successful UsbHostApi.openForFfi call. The Dart FFI layer takes over I/O from here.

Constructors

UsbOpenResult({required int platformHandle, required int vendorId, required int productId, String? serialNumber, required int claimedInterfaceNumber, required int bulkInEndpoint, required int bulkOutEndpoint, required int wMaxPacketSizeOut})

Properties

bulkInEndpoint ↔ int
getter/setter pair
bulkOutEndpoint ↔ int
getter/setter pair
claimedInterfaceNumber ↔ int
Interface index that the native side has claimed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
platformHandle ↔ int
Android: file descriptor from UsbDeviceConnection.getFileDescriptor(). macOS/Windows: 0 (FFI matches the device via VID+PID+serial).
getter/setter pair
productId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber ↔ String?
getter/setter pair
vendorId ↔ int
getter/setter pair
wMaxPacketSizeOut ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → UsbOpenResult