closeHandle abstract method

Future<void> closeHandle({
  1. required int handleId,
})

Releases the claimed interface and closes the libusb device handle. Also terminates the worker isolate that owned the handle.

Implementation

Future<void> closeHandle({required int handleId});