closeHandle method
Releases the claimed interface and closes the libusb device handle. Also terminates the worker isolate that owned the handle.
Implementation
@override
Future<void> closeHandle({required int handleId}) async {
_handles.remove(handleId);
}